@@ -435,8 +435,8 @@ SCR_Init(void)
 	scr_graphshift = Cvar_Get("graphshift", "0", 0);
 	scr_drawall = Cvar_Get("scr_drawall", "0", 0);
 	gl_hudscale = Cvar_Get("gl_hudscale", "-1", CVAR_ARCHIVE);
-	gl_consolescale = Cvar_Get("gl_consolescale", "1", CVAR_ARCHIVE);
-	gl_menuscale = Cvar_Get("gl_menuscale", "1", CVAR_ARCHIVE);
+	gl_consolescale = Cvar_Get("gl_consolescale", "-1", CVAR_ARCHIVE);
+	gl_menuscale = Cvar_Get("gl_menuscale", "-1", CVAR_ARCHIVE);
 
 	/* register our commands */
 	Cmd_AddCommand("timerefresh", SCR_TimeRefresh_f);
@@ -492,7 +492,6 @@ SCR_DrawLoading(void)
 		return;
 	}
 
-	scr_draw_loading = false;
 	Draw_GetPicSize(&w, &h, "loading");
 	Draw_PicScaled((viddef.width - w * scale) / 2, (viddef.height - h * scale) / 2, "loading", scale);
 }
@@ -609,6 +608,9 @@ SCR_BeginLoadingPlaque(void)
 	}
 
 	SCR_UpdateScreen();
+
+	scr_draw_loading = false;
+
 	SCR_StopCinematic();
 	cls.disable_screen = Sys_Milliseconds();
 	cls.disable_servercount = cl.servercount;
@@ -1441,9 +1443,18 @@ SCR_UpdateScreen(void)
 		return; /* not initialized yet */
 	}
 
-	separation[0] = 0;
-	separation[1] = 0;
-	numframes = 1;
+	if ( gl_stereo->value )
+	{
+		numframes = 2;
+		separation[0] = -gl_stereo_separation->value / 2;
+		separation[1] = +gl_stereo_separation->value / 2;
+	}		
+	else
+	{
+		separation[0] = 0;
+		separation[1] = 0;
+		numframes = 1;
+	}
 
 	for (i = 0; i < numframes; i++)
 	{
@@ -1454,8 +1465,14 @@ SCR_UpdateScreen(void)
 			/* loading plaque over black screen */
 			int w, h;
 
-			R_SetPalette(NULL);
-			scr_draw_loading = false;
+			if(i == 0){
+				R_SetPalette(NULL);
+			}
+
+			if(i == numframes - 1){
+				scr_draw_loading = false;
+			}
+
 			Draw_GetPicSize(&w, &h, "loading");
 			Draw_PicScaled((viddef.width - w * scale) / 2, (viddef.height - h * scale) / 2, "loading", scale);
 		}
@@ -1552,7 +1569,32 @@ SCR_UpdateScreen(void)
 	GLimp_EndFrame();
 }
 
-float
+static float
+SCR_ClampScale(float scale)
+{
+	float f;
+
+	f = viddef.width / 320.0f;
+	if (scale > f)
+	{
+		scale = f;
+	}
+
+	f = viddef.height / 240.0f;
+	if (scale > f)
+	{
+		scale = f;
+	}
+
+	if (scale < 1)
+	{
+		scale = 1;
+	}
+
+	return scale;
+}
+
+static float
 SCR_GetDefaultScale(void)
 {
 	int i = viddef.width / 640;
@@ -1597,11 +1639,11 @@ SCR_DrawCrosshair(void)
 	}
 	else
 	{
-		scale = crosshair_scale->value;
+		scale = SCR_ClampScale(crosshair_scale->value);
 	}
 
-	Draw_PicScaled(scr_vrect.x + ((scr_vrect.width - crosshair_width) >> 1),
-			scr_vrect.y + ((scr_vrect.height - crosshair_height) >> 1),
+	Draw_PicScaled(scr_vrect.x + (scr_vrect.width - crosshair_width * scale) / 2,
+			scr_vrect.y + (scr_vrect.height - crosshair_height * scale) / 2,
 			crosshair_pic, scale);
 }
 
@@ -1610,13 +1652,21 @@ SCR_GetHUDScale(void)
 {
 	float scale;
 
-	if (gl_hudscale->value < 0)
+	if (!scr_initialized)
+	{
+		scale = 1;
+	}
+	else if (gl_hudscale->value < 0)
 	{
 		scale = SCR_GetDefaultScale();
 	}
+	else if (gl_hudscale->value == 0) /* HACK: allow scale 0 to hide the HUD */
+	{
+		scale = 0;
+	}
 	else
 	{
-		scale = gl_hudscale->value;
+		scale = SCR_ClampScale(gl_hudscale->value);
 	}
 
 	return scale;
@@ -1627,13 +1677,17 @@ SCR_GetConsoleScale(void)
 {
 	float scale;
 
-	if (gl_consolescale->value < 0)
+	if (!scr_initialized)
+	{
+		scale = 1;
+	}
+	else if (gl_consolescale->value < 0)
 	{
 		scale = SCR_GetDefaultScale();
 	}
 	else
 	{
-		scale = gl_consolescale->value;
+		scale = SCR_ClampScale(gl_consolescale->value);
 	}
 
 	return scale;
@@ -1644,13 +1698,17 @@ SCR_GetMenuScale(void)
 {
 	float scale;
 
-	if (gl_menuscale->value < 0)
+	if (!scr_initialized)
+	{
+		scale = 1;
+	}
+	else if (gl_menuscale->value < 0)
 	{
 		scale = SCR_GetDefaultScale();
 	}
 	else
 	{
-		scale = gl_menuscale->value;
+		scale = SCR_ClampScale(gl_menuscale->value);
 	}
 
 	return scale;
