@@ -239,7 +239,7 @@ AL_PlayChannel(channel_t *ch)
 	}
 
 	/* Clamp volume */
-	vol = ch->oal_vol + s_volume->value;
+	vol = ch->oal_vol;
 
 	if (vol > 1.0f)
 	{
@@ -445,6 +445,11 @@ AL_AddLoopSounds(void)
 		ch->dist_mult = SOUND_LOOPATTENUATE;
 		ch->end = paintedtime + sc->length;
 
+		/* it seems like looped sounds are always played at full volume
+		 * see SDL_AddLoopSounds() which calls SDL_SpatializeOrigin() with volume 255.0f
+		 * so set it to full volume (1.0 * s_volume). */
+		ch->oal_vol = s_volume->value;
+
 		AL_PlayChannel(ch);
 	}
 }
@@ -602,7 +607,6 @@ AL_Update(void)
 	/* set listener (player) parameters */
 	AL_CopyVector(listener_forward, orientation);
 	AL_CopyVector(listener_up, orientation + 3);
- 	qalListenerf(AL_GAIN, s_volume->value);
 	qalListenerf(AL_MAX_GAIN, s_openal_maxgain->value);
 	qalDistanceModel(AL_LINEAR_DISTANCE_CLAMPED);
 	qalListener3f(AL_POSITION, AL_UnpackVector(listener_origin));
